@@ -30,7 +30,9 @@ class Proxy(object):
         self.ip_data = 0
         try:
             proxy = spider.proxy
-            self.proxy_name = proxy.get('name'),
+            self.user = proxy.get("user")
+            self.pwd = proxy.get("pwd")
+            self.proxy_name = proxy.get('name')
             self.proxies = ProxyGetter(
                 proxy.get('url'),
                 proxy.get('name'),
@@ -95,10 +97,8 @@ class Proxy(object):
                 ip_raw = random.choice(self.ip_list)
                 self.ip_list.remove(ip_raw)
                 request.meta["proxy"] = ip_raw
-                if self.proxy_name is 'kuaidaili_ip':
-                    request.headers['Proxy-Authorization'] = basic_auth_header(
-                        '${username}', '${password}'
-                    )
+                if self.proxy_name == 'kuaidaili_ip':
+                    request.headers['Proxy-Authorization'] = basic_auth_header(self.user, self.pwd)
                     request.headers["Connection"] = "close"
             else:
                 logging.info('代理列表为空')
